@@ -27,7 +27,7 @@ use Rose::Object::MakeMethods::Generic (
 
 );
 
-our $VERSION = '0.19';
+our $VERSION = '0.20';
 
 =head1 NAME
 
@@ -306,13 +306,14 @@ sub _convert_field_to_menu {
         : 'Rose::HTML::Form::Field::PopUpMenu';
 
     my $menu = $menu_class->new(
-        id       => $field->id,
-        name     => $field_name,
-        type     => 'menu',
-        class    => 'interrelated ' . ( $field->class || '' ),
-        label    => $field->label,
-        tabindex => $field->tabindex,
-        rank     => $field->rank
+        id          => $field->id,
+        name        => $field_name,
+        type        => 'menu',
+        class       => 'interrelated ' . ( $field->class || '' ),
+        label       => $field->label,
+        tabindex    => $field->tabindex,
+        rank        => $field->rank,
+        description => $field->description,
     );
     $self->__set_menu_options( $menu, $rel_info ) or return;
 
@@ -362,7 +363,8 @@ sub _convert_field_to_autocomplete {
         maxlength => $field->maxlength,
         autocomplete =>
             $app->uri_for( '/' . $controller->path_prefix, 'autocomplete' ),
-        limit => 30,
+        limit       => 30,
+        description => $field->description,
     );
 
     # must delete first since field() will return cached $field
